<?php
/**
 * Forum Permissions bbPress
 *
 * @package   forum-permissions-bbpress
 * @author    Verdant Studio
 * @copyright 2022 Forum Permissions bbPress
 * @link      https://verdant.studio
 *
 * Plugin Name:     Forum Permissions bbPress
 * Plugin URI:      https://verdant.studio/forum-permissions-bbpress
 * Description:     Restrict the forum permissions per user role
 * Version:         1.0.7
 * Author:          Verdant Studio
 * Author URI:      https://verdant.studio
 * Text Domain:     forum-permissions-bbpress
 * Domain Path:     /languages
 * Requires PHP:    7.1
 * Requires WP:     5.5.0
 * Namespace:       ForumPermissionsBbpress
 */

declare(strict_types=1);

/**
 * Define the default root file of the plugin
 *
 * @since 1.0.0
 */
const FORUM_PERMISSIONS_BBPRESS_PLUGIN_FILE = __FILE__;

/**
 * Load PSR4 autoloader
 *
 * @since 1.0.0
 */
$forum_permissions_bbpress_autoloader = require plugin_dir_path(FORUM_PERMISSIONS_BBPRESS_PLUGIN_FILE) . 'vendor/autoload.php';

/**
 * Setup hooks (activation, deactivation, uninstall)
 *
 * @since 1.0.0
 */
register_activation_hook(__FILE__, array( 'ForumPermissionsBbpress\Config\Setup', 'activation' ));
register_deactivation_hook(__FILE__, array( 'ForumPermissionsBbpress\Config\Setup', 'deactivation' ));
register_uninstall_hook(__FILE__, array( 'ForumPermissionsBbpress\Config\Setup', 'uninstall' ));

/**
 * Bootstrap the plugin
 *
 * @since 1.0.0
 */
if (! class_exists('\ForumPermissionsBbpress\Bootstrap')) {
    wp_die(__('Forum Permissions bbPress is unable to find the Bootstrap class.', 'forum-permissions-bbpress'));
}
add_action(
    'plugins_loaded',
    static function () use ($forum_permissions_bbpress_autoloader) {
        /**
         * @see \ForumPermissionsBbpress\Bootstrap
         */
        try {
            new \ForumPermissionsBbpress\Bootstrap($forum_permissions_bbpress_autoloader);
        } catch (Exception $e) {
            wp_die(__('Forum Permissions bbPress is unable to run the Bootstrap class.', 'forum-permissions-bbpress'));
        }
    }
);

/**
 * Create a main function for external uses
 *
 * @return \ForumPermissionsBbpress\Common\Functions
 * @since 1.0.0
 */
function forum_permissions_bbpress(): \ForumPermissionsBbpress\Common\Functions
{
    return new \ForumPermissionsBbpress\Common\Functions();
}
