<?php
/**
 * Forum Permissions bbPress
 *
 * @package   forum-permissions-bbpress
 * @author    Verdant Studio
 * @copyright 2022 Forum Permissions bbPress
 * @link      https://verdant.studio
 */

declare(strict_types=1);

namespace ForumPermissionsBbpress\App\Backend;

use ForumPermissionsBbpress\Common\Abstracts\Base;

/**
 * Class Hooks
 *
 * @package ForumPermissionsBbpress\App\Backend
 * @since 1.0.0
 */
class Hooks extends Base {

	/**
	 * Initialize the class.
	 *
	 * @since 1.0.0
	 */
	public function init() {
		/**
		 * This backend class is only being instantiated in the backend as requested in the Bootstrap class
		 *
		 * @see Requester::isAdminBackend()
		 * @see Bootstrap::__construct
		 */
		add_action( 'save_post', array( $this, 'fpb_save_meta_boxes' ) );
	}

	/**
	 * Save the meta boxes.
	 *
	 * @since 1.0.0
	 */
	public function fpb_save_meta_boxes( $post_id ) {
		if ( 'forum' != get_post_type( $post_id ) ) {
			return;
		}

		if ( isset( $_POST['fpb_new_topic_disallowed_roles'] ) ) {
			$disallowed_roles = is_array( $_POST['fpb_new_topic_disallowed_roles'] ) ? array_map( 'sanitize_text_field', $_POST['fpb_new_topic_disallowed_roles'] ) : array();

			update_post_meta( $post_id, 'fpb_new_topic_disallowed_roles', $disallowed_roles );
		} else {
			delete_post_meta( $post_id, 'fpb_new_topic_disallowed_roles' );
		}

		if ( isset( $_POST['fpb_new_reply_disallowed_roles'] ) ) {
			$disallowed_roles = is_array( $_POST['fpb_new_reply_disallowed_roles'] ) ? array_map( 'sanitize_text_field', $_POST['fpb_new_reply_disallowed_roles'] ) : array();

			update_post_meta( $post_id, 'fpb_new_reply_disallowed_roles', $disallowed_roles );
		} else {
			delete_post_meta( $post_id, 'fpb_new_reply_disallowed_roles' );
		}
	}
}
