<?php
/**
 * Forum Permissions bbPress
 *
 * @package   forum-permissions-bbpress
 * @author    Verdant Studio
 * @copyright 2022 Forum Permissions bbPress
 * @link      https://verdant.studio
 */

declare(strict_types=1);

namespace ForumPermissionsBbpress\App\Frontend;

use ForumPermissionsBbpress\Common\Abstracts\Base;

/**
 * Class Hooks
 *
 * @package ForumPermissionsBbpress\App\Frontend
 * @since 1.0.0
 */
class Hooks extends Base {

	/**
	 * Initialize the class.
	 *
	 * @since 1.0.0
	 */
	public function init() {
		/**
		 * This frontend class is only being instantiated in the frontend as requested in the Bootstrap class
		 *
		 * @see Requester::isFrontend()
		 * @see Bootstrap::__construct
		 *
		 * Add plugin code here
		 */
		if ( class_exists( '\bbPress' ) ) {
			add_action( 'bbp_has_topics', array( $this, 'fpb_determine_topic_form_visibility' ) );
			add_filter( 'bbp_current_user_can_access_create_reply_form', [$this, 'fpb_determine_reply_form_visibility']);
		}
	}

	/**
	 * Determine wether or not to show the create topic form.
	 *
	 * @since 1.0.0
	 */
	public function fpb_determine_topic_form_visibility( $have_posts ) {
		global $post;

		$disallowed_roles = get_post_meta( $post->ID, 'fpb_new_topic_disallowed_roles', true );
		$disallowed_roles = $disallowed_roles ? $disallowed_roles : array();

		foreach ( $disallowed_roles as $role ) {
			if ( in_array( $role, wp_get_current_user()->roles ) ) {
				add_filter( 'bbp_current_user_can_access_create_topic_form', '__return_false' );
			}
		}

		return $have_posts;
	}

	/**
	 * Determine wether or not to show the create reply form.
	 *
	 * @since 1.0.4
	 *
	 * @return bool
	 */
	public function fpb_determine_reply_form_visibility( $retval ) {
		$disallowed_roles = get_post_meta( bbp_get_forum_id(), 'fpb_new_reply_disallowed_roles', true );
		$disallowed_roles = $disallowed_roles ? $disallowed_roles : array();

		foreach ( $disallowed_roles as $role ) {
			if ( in_array( $role, wp_get_current_user()->roles ) ) {
				return false;
			}
		}

		return $retval;
	}
}
