<?php
/**
 * Forum Permissions bbPress
 *
 * @package   forum-permissions-bbpress
 * @author    Verdant Studio
 * @copyright 2022 Forum Permissions bbPress
 * @link      https://verdant.studio
 */

declare(strict_types=1);

namespace ForumPermissionsBbpress\App\General;

use ForumPermissionsBbpress\Common\Abstracts\Base;

/**
 * Class MetaBoxes
 *
 * @package ForumPermissionsBbpress\App\General
 * @since 1.0.0
 */
class MetaBoxes extends Base {

	/**
	 * Initialize the class.
	 *
	 * @since 1.0.0
	 */
	public function init() {
		/**
		 * This general class is always being instantiated as requested in the Bootstrap class
		 *
		 * @see Bootstrap::__construct
		 */
		if ( class_exists( '\bbPress' ) ) {
			add_action( 'add_meta_boxes', array( $this, 'register' ) );
		}
	}

	/**
	 * Register post type
	 *
	 * @since 1.0.0
	 */
	public function register() {
		add_meta_box(
			'forum-permissions-bbpress-disallow-topic-creation',
			__( 'Disallow Topic Creation', 'forum-permissions-bbpress' ),
			array( $this, 'render_topic_fields' ),
			'forum',
			'side',
			'default'
		);

		add_meta_box(
			'forum-permissions-bbpress-disallow-reply-creation',
			__( 'Disallow Reply Creation', 'forum-permissions-bbpress' ),
			array( $this, 'render_reply_fields' ),
			'forum',
			'side',
			'default'
		);
	}

	/**
	 * Get the bbPress user roles.
	 *
	 * @since 1.0.0
	 */
	public function get_bbp_roles() {
		foreach ( bbp_get_dynamic_roles() as $role_id => $role ) {
			$roles[ $role_id ] = $role;
		}
		return $roles;
	}

	/**
	 * Render the topic fields
	 *
	 * @since 1.0.0
	 */
	public function render_topic_fields() {
		global $post;

		$disallowed_roles = get_post_meta( $post->ID, 'fpb_new_topic_disallowed_roles', true );
		$disallowed_roles = $disallowed_roles ? $disallowed_roles : array();

		foreach ( $this->get_bbp_roles() as $role_id => $role ) {
			$checked = in_array( $role_id, $disallowed_roles ) ? 'checked' : '';
			printf( '<input type="checkbox" name="fpb_new_topic_disallowed_roles[]" value="%s" %s>%s<br>', $role_id, $checked, $role['name'] );
		}
	}

	/**
	 * Render the reply fields
	 *
	 * @since 1.0.4
	 */
	public function render_reply_fields() {
		global $post;

		$disallowed_roles = get_post_meta( $post->ID, 'fpb_new_reply_disallowed_roles', true );
		$disallowed_roles = $disallowed_roles ? $disallowed_roles : array();

		foreach ( $this->get_bbp_roles() as $role_id => $role ) {
			$checked = in_array( $role_id, $disallowed_roles ) ? 'checked' : '';
			printf( '<input type="checkbox" name="fpb_new_reply_disallowed_roles[]" value="%s" %s>%s<br>', $role_id, $checked, $role['name'] );
		}
	}
}
